// resources/js/Pages/Users/ExportButton.jsx
import Button from '@/Components/Buttons/Button';
import Modal from '@/Components/Modal';
import React, { useState } from 'react';
import toast from 'react-hot-toast';

export default function Export({ isModalOpen, handleCloseModal }) {
    const [loading, setLoading] = useState(false);

    const handleExport = async () => {
        setLoading(true);

        try {
            const response = await fetch(route('lead.export'), {
                method: 'GET',
                headers: {
                    'X-Requested-With': 'XMLHttpRequest',
                },
            });

            if (!response.ok) {
                throw new Error('Erro ao exportar contatos.');
            }

            const blob = await response.blob();
            const url = window.URL.createObjectURL(blob);
            const link = document.createElement('a');
            link.href = url;
            link.setAttribute('download', 'Contatos.xlsx');
            document.body.appendChild(link);
            link.click();
            link.remove();

            handleCloseModal();
            toast.success('Contatos exportados com sucesso!');
        } catch (error) {
            toast.error(error.message);
        } finally {
            setLoading(false);
        }
    };

    return (
        <Modal isOpen={isModalOpen} onClose={handleCloseModal} title='Exportar contatos'>
            <p className='text-[.85rem] pt-4'>
                Exporte rapidamente um arquivo csv com detalhes completos dos seus contatos
            </p>

            <div className='flex justify-center mt-5'>
                <Button onClick={handleExport} className="mt-4" type="button" disabled={loading}>Exportar Contatos</Button>
            </div>
        </Modal>
    );
};
